==> haskell-th-desugar-1.14-53-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.14
visibility:           public
id:                   th-desugar-1.14-LUwB5HckKnV58pnkvPjreC
key:                  th-desugar-1.14-LUwB5HckKnV58pnkvPjreC
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  b0d8723e5c14c72e3d58e50bd83068e0
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-desugar-1.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-desugar-1.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-desugar
hs-libraries:         HSth-desugar-1.14-LUwB5HckKnV58pnkvPjreC
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0 mtl-2.2.2
    ordered-containers-0.2.3-Ee6QR9weM8P1AVLTbz9WQP
    syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY
    th-orphans-0.13.14-IFdr808Ei4NTG64FhXomg
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html:         /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar-1.14-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.14
visibility:           public
id:                   th-desugar-1.14-6aBpWp03Zkp1fOKnqywQ0g
key:                  th-desugar-1.14-6aBpWp03Zkp1fOKnqywQ0g
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  90202c045353f6609c431cb189a27b18
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-desugar-1.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-desugar-1.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-desugar
hs-libraries:         HSth-desugar-1.14-6aBpWp03Zkp1fOKnqywQ0g
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0 mtl-2.2.2
    ordered-containers-0.2.3-Ee6QR9weM8P1AVLTbz9WQP
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY
    th-orphans-0.13.14-9IVv0eQKqVy5rA0nZ47ezc
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html:         /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
